@@ -15,7 +15,9 @@ from oauth2client.service_account import ServiceAccountCredentials
 class EasySpreadsheet():
     
     def __init__(self, auth_json: dict, spreadsheet_id: str, sheet_name: str = ""):
-
+        """
+        Easy Spreadsheet
+        """
 
         self.table = None
 
@@ -92,31 +94,31 @@ class EasySpreadsheet():
         self.table = pd.DataFrame(rows)
         
 
-    def _convert_to_str(self, value):
+
+
+    def _parse(self, value):
         if type(value) is list or type(value) is dict:
-            v = json.dumps(value, ensure_ascii=False)
+            v = value
         else:
-            v = str(value)
+            try:
+                v = json.loads(value)
+            except:
+                v = value
 
         return v
 
-    def _parse(self, value):
-        try:
-            if type(value) is list or type(value) is dict:
-                v = value
-            elif len(value) != 0 and (value[0] == "{" or value[0] == "["):
-                v = json.loads(value)
-            else:
-                v = str(value)
-        except:
-            v = str(value)
+    def _convert(self, value):
+        if type(value) is list or type(value) is dict:
+            v = json.dumps(value, ensure_ascii=False)
+        else:
+            v = value
 
         return v
 
     def _make_sheet_row(self, row):
         temp = []
         for p in row:
-            v = self._convert_to_str(p)
+            v = self._convert(p)
 
             temp.append(v)
 
